/* 
 * Copyright (c) 1999  Machine Vision Holdings Incorporated
 *
 * Template driver used: Copyright (c) 1998  Metro Link Incorporated
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * THE X CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
 * OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * Except as contained in this notice, the name of the Metro Link shall not be
 * used in advertising or otherwise to promote the sale, use or other dealings
 * in this Software without prior written authorization from Metro Link.
 *
 */
/* $XFree86: xc/programs/Xserver/hw/xfree86/input/elo/elo.h,v 1.2 1999/08/22 05:57:37 dawes Exp $ */

#ifndef	_ELOUSB_H_
#define _ELOUSB_H_

/******************************************************************************
 *		Definitions
 *				structs, typedefs, #defines, enums
 *****************************************************************************/
#define ELO_PACKET_SIZE		10
															  /* Note: some of them are not supported by the E281-2310 *//* JPM */

#define ELO_SYNC_BYTE       'U'	/* Sync byte. First of a packet.    */
#define ELO_TOUCH           'T'	/* Report of touchs and motions.    */
#define ELO_OWNER           'O'	/* Report vendor name.          */
#define ELO_ID              'I'	/* Report of type and features.     */
#define ELO_MODE            'M'	/* Set current operating mode.      */
#define ELO_PARAMETER       'P'	/* Set the serial parameters.       */
#define ELO_REPORT          'B'	/* Set touch reports timings.       */
#define ELO_CALIBRATION     'C'	/* Calibration command.         */
#define ELO_ACK             'A'	/* Acknowledge packet           */
#define ELO_SERIAL_IO       '0'	/* Indicator byte for PARAMETER command */

#define ELO_INIT_CHECKSUM       0xAA	/* Initial value of checksum.       */

#define ELO_PRESS               0x01	/* Flags in ELO_TOUCH status byte   */
#define ELO_STREAM              0x02
#define ELO_RELEASE             0x04

#define ELO_TOUCH_MODE          0x01	/* Flags in ELO_MODE command        */
#define ELO_STREAM_MODE         0x02
#define ELO_UNTOUCH_MODE        0x04
#define ELO_RANGE_CHECK_MODE    0x40
#define ELO_ENABLE_Z_MODE       0x80
#define ELO_TRIM_MODE           0x02
#define ELO_CALIB_MODE          0x04
#define ELO_SCALING_MODE        0x08
#define ELO_TRACKING_MODE       0x40

#define ELO_SERIAL_SPEED        0x06	/* Flags for high speed serial
										 * (19200) */
#define ELO_SERIAL_MASK         0xF8

#define ELO_MAX_WRONG_PACKETS   200		/* Number of wrong packets to accept
										 * before giving up when looking for
										 * a specific packet type */
#define ELO_MAX_EMPTY_PACKETS   3	/* Number of empty reads to accept before 
									 * giving up when looking for a reply */
#define ELO_MAX_WAIT        100000	/* Max wait time for a reply (microsec) */

#define ELO_UNTOUCH_DELAY   10	/* 100 ms               */
#define ELO_REPORT_DELAY    2	/* 20 ms or 50 motion reports/s     */

#define NORMAL			0
#define LEFTOF			1
#define RIGHTOF			2
#define ABOVE				3
#define BELOW				4
#define CLONE				5

#define NUMEVENTS		64
#define EVENTS_LIMIT	200


typedef struct _EloPrivateRec
{
	int min_x;				/* Minimum x reported by calibration        */
	int max_x;				/* Maximum x                    */
	int min_y;				/* Minimum y reported by calibration        */
	int max_y;				/* Maximum y                    */
	int button_threshold;		/* Z > button threshold = button click */
	Bool button_down;			/* is the "button" currently down */
	int button_number;			/* which button to report */
	int reporting_mode;			/* TS_Raw or TS_Scaled */
	int screen_num;				/* Screen associated with the device        */
	int x_offset;					/* Screen offset X coordinate		*/
	int y_offset;					/* Screen offset Y coordinate		*/
	int screen_width;			/* Width of the associated X screen     */
	int screen_height;			/* Height of the screen             */
  int t_mode;		/* Set if the Twin mode 		*/
	int swap_xy;
	int cal_threshold;
	XISBuffer *buffer;
}
EloPrivateRec, *EloPrivatePtr;


/******************************************************************************
 *		Declarations
 *****************************************************************************/

static Bool DeviceControl (DeviceIntPtr, int);
static Bool DeviceControlSilence (DeviceIntPtr, int);
static void ReadInput (InputInfoPtr);
static int ControlProc (InputInfoPtr, xDeviceCtl *);
static void CloseProc (InputInfoPtr);
static int SwitchMode (ClientPtr, DeviceIntPtr, int);
static Bool ConvertProc (InputInfoPtr, int, int, int, int, int, int, int, int, int *, int *);
static Bool QueryHardware (LocalDevicePtr local);

static InputInfoPtr EloPreInit(InputDriverPtr drv, IDevPtr dev, int flags);

#endif /* _ELOUSB_H_ */
